#!/bin/sh
#
# NRPE installer
# 11/14/2003 Grzegorz Kwiatkowski
#
#
PROGNAME="NRPE installer"
PROGPATH=`echo $0 | sed -e 's,[\\/][^\\/][^\\/]*$,,'`
VERSION=`echo '$Revision: 1.0 $' | sed -e 's/[^0-9.]//g'`

print_usage() {
  echo "Usage:"
  echo "  $PROGNAME --install -u <nrpe user> -g <nrpe group> -p <nagios path>"
  echo "  $PROGNAME --help"
  echo "  $PROGNAME --version"
}

print_note() {
  echo ""
  echo "If you are going to use check_oracle, you will need ORACLE_HOME configured"
  echo "in /etc/oratab for all SIDs or *:<ORACLE_HOME>:N entry must be present."
  echo "Be also aware that check_oracle script is sensitive on comments in top of oratab"
  echo "file so you must remove it."
  echo "After installation please restart xinetd (/etc/init.d/xinetd restart)."
  echo "You may also wish to test NRPE. To do it siply telnet localhost 5999."
  echo ""
}

print_help() {
  echo $PROGNAME $VERSION
  echo "11/14/2003 Grzegorz Kwiatkowski, Comarch Global, Inc."
  echo ""
  print_usage
  echo ""
  echo "Installs Nagios NRPE agent on linux."
  echo ""
  echo "--install"
  echo "   Installs NRPE in default /usr/local/nagios using default user and group"
  echo "--install -u <nrpe user> -g <nrpe group> -p <nagios path>"
  echo "   Installs NRPE in specific location using specific user and group"
  echo "--help"
  echo "   Print this help screen"
  echo "--version"
  echo "   Print version and license information"
  print_note
}


installpath=/usr/local/nagios
nuser=nagios
ngroup=nagios

while test -n "$1"; do
    case "$1" in
        --help)
            print_help
            exit 0
            ;;
        -h)
            print_help
            exit 0
            ;;
        --version)
            echo $PROGNAME $VERSION
            exit $STATE_OK
            ;;
        -V)
            echo $PROGNAME $VERSION
            exit $STATE_OK
            ;;
        -p)
            installpath=$2
            shift
            ;;
        -u)
            nuser=$2
            shift
            ;;
        -g)
            ngroup=$2
            shift
            ;;
        --install)
            doinstall=1
            shift
            ;;
        *)
            echo "Unknown argument: $1"
            print_usage
            exit 1
            ;;
    esac
    shift
done

if [ -z $doinstall ]; then
    echo ""
    echo "Wrong usage!"
    echo ""
    print_usage
    exit 1
fi

echo ""
echo "Installing NRPE using:"
echo "  path: $installpath"
echo "  user: $nuser"
echo "  group: $ngroup" 
echo ""

echo ".";sleep 1;echo ".";sleep 1;echo ".";sleep 1;echo ""

mkdir -p $installpath

groupadd $ngroup 
useradd -g $ngroup $nuser 

cp -R libexec $installpath

cp -R bin $installpath

chown -R $nuser:$ngroup $installpath

cp nrpe.cfg /etc

echo "command[check_users]=$installpath/libexec/check_users -w \$ARG1$ -c \$ARG2$" >> /etc/nrpe.cfg
echo "command[check_load]=$installpath/libexec/check_load -w \$ARG1$ -c \$ARG2$" >> /etc/nrpe.cfg
echo "command[check_disk]=$installpath/libexec/check_disk -w \$ARG1$ -c \$ARG2$ -p \$ARG3$" >> /etc/nrpe.cfg
echo "command[check_procs]=$installpath/libexec/check_procs -w \$ARG1$ -c \$ARG2$ -s \$ARG3$" >> /etc/nrpe.cfg
echo "command[check_oracle]=$installpath/libexec/check_oracle --login \$ARG1$" >> /etc/nrpe.cfg
echo "command[check_log]=$installpath/libexec/check_log -F \$ARG1$ -O \$ARG2$ -q \$ARG3$" >> /etc/nrpe.cfg

echo "# default: on" > /etc/xinetd.d/nrpe
echo "# description: NRPE" >> /etc/xinetd.d/nrpe
echo "        service nrpe" >> /etc/xinetd.d/nrpe
echo "        {" >> /etc/xinetd.d/nrpe
echo "                flags           = REUSE" >> /etc/xinetd.d/nrpe
echo "                socket_type     = stream" >> /etc/xinetd.d/nrpe
echo "                wait            = no" >> /etc/xinetd.d/nrpe
echo "                user            = $nuser" >> /etc/xinetd.d/nrpe
echo "                server          = $installpath/bin/nrpe" >> /etc/xinetd.d/nrpe
echo "                server_args     = -c /etc/nrpe.cfg --inetd" >> /etc/xinetd.d/nrpe
echo "                log_on_failure  += USERID" >> /etc/xinetd.d/nrpe
echo "                disable         = no" >> /etc/xinetd.d/nrpe
echo "        }" >> /etc/xinetd.d/nrpe

echo "nrpe            5666/tcp                        # Nagios Remote Process Exec" >> /etc/services

echo ""
echo "Done."

print_note

exit 0

